@@ -422,8 +422,7 @@ void HistoryImport::parsePidginTxt(QFile &file, struct Log *log, QDate date)
 
 	// this is to collect unknown nicknames (the list stores the index in log->messages of the messages that used the nickname)
 	// the bool says if that nickname is incoming (only used when the list is empty)
-	typedef QHash<QString, QPair<bool, QList<int> > > NickNameHash;
-	NickNameHash nicknames;
+	QHash<QString, QPair<bool, QList<int> > > nicknames;
 
 	QTextStream str(&file);
 	// utf-8 seems to be default for pidgins-txt logs
@@ -482,15 +481,15 @@ void HistoryImport::parsePidginTxt(QFile &file, struct Log *log, QDate date)
 		log->messages.append(message);
 
 	// check if we can guess which nickname belongs to us
-	NickNameHash::iterator itr;
-	NickNameHash::const_iterator itr2;
+	QHash<QString, QPair<bool, QList<int> > >::iterator itr;
+	QHash<QString, QPair<bool, QList<int> > >::iterator itr2;
 	for (itr = nicknames.begin(); itr != nicknames.end(); ++itr) {
 		if (itr->second.isEmpty()) // no work for this one
 			continue;
 		bool haveAnother = false, lastIncoming = false;
 		// check against all other nicknames
-		for (itr2 = nicknames.constBegin(); itr2 != nicknames.constEnd(); ++itr2) {
-			if (itr2 == NickNameHash::const_iterator(itr)) // skip ourselve
+		for (itr2 = nicknames.begin(); itr2 != nicknames.end(); ++itr2) {
+			if (itr2 == itr) // skip ourselves
 				continue;
 
 			// if there is another unknown nickname, we have no chance to guess which is our
@@ -506,7 +505,7 @@ void HistoryImport::parsePidginTxt(QFile &file, struct Log *log, QDate date)
 			}
 		}
 		// we now can guess the incoming value of itr, namely !lastIncoming
-		if (haveAnother && itr2 == nicknames.constEnd()) {
+		if (haveAnother && itr2 == nicknames.end()) {
 			// inform the user
 			if (lastIncoming)
 				detailsCursor.insertText(i18n("INFORMATION: Guessed %1 to be one of your nicks.\n", itr.key()));
@@ -517,7 +516,7 @@ void HistoryImport::parsePidginTxt(QFile &file, struct Log *log, QDate date)
 			int i;
 			for (i = 0; i < itr->second.size(); i++)
 				log->messages[itr->second.at(i)].incoming = !lastIncoming;
-			itr->second.clear(); // we are finished with theese indexes
+			itr->second.clear(); // we are finished with these indexes
 		}
 	}
 
