@@ -513,6 +513,22 @@ WeightedNameRecordList::WeightedNameRecordList(const QList<XMPP::NameRecord> &li
 	append(list);
 }
 
+WeightedNameRecordList::WeightedNameRecordList(const WeightedNameRecordList &other)
+{
+	*this = other;
+}
+
+WeightedNameRecordList &WeightedNameRecordList::operator=(const WeightedNameRecordList &other)
+{
+	priorityGroups = other.priorityGroups;
+	if (other.currentPriorityGroup != other.priorityGroups.end()) {
+		currentPriorityGroup = priorityGroups.find(other.currentPriorityGroup.key());
+	} else {
+		currentPriorityGroup = priorityGroups.end();
+	}
+	return *this;
+}
+
 WeightedNameRecordList::~WeightedNameRecordList() {
 }
 
@@ -1258,7 +1274,10 @@ void ServiceResolver::handle_srv_ready(const QList<XMPP::NameRecord> &r)
 
 	/* lookup srv pointers */
 	d->srvList << r;
-	try_next_srv();
+	emit srvReady();
+	if (d->requestedProtocol != HappyEyeballs) {
+		try_next_srv();
+	}
 }
 
 /* failed the srv lookup, but we might have a fallback host in the srvList */
@@ -1274,7 +1293,10 @@ void ServiceResolver::handle_srv_error(XMPP::NameResolver::Error e)
 	cleanup_resolver(static_cast<XMPP::NameResolver*>(sender()));
 
 	/* srvList already contains a failsafe host, try that */
-	try_next_srv();
+	emit srvFailed();
+	if (d->requestedProtocol != HappyEyeballs) {
+		try_next_srv();
+	}
 }
 
 /* hosts resolved, now try to connect to them */
@@ -1416,6 +1438,23 @@ bool ServiceResolver::hasPendingSrv() const
 	return !d->srvList.isEmpty();
 }
 
+ServiceResolver::ProtoSplit ServiceResolver::happySplit()
+{
+	Q_ASSERT(d->requestedProtocol == HappyEyeballs);
+	ProtoSplit s;
+	s.ipv4 = new ServiceResolver(this);
+	s.ipv4->setProtocol(IPv4);
+	s.ipv4->d->srvList = d->srvList;
+	s.ipv4->d->hostList = d->hostList;
+	s.ipv4->d->domain = d->domain;
+	s.ipv6 = new ServiceResolver(this);
+	s.ipv6->setProtocol(IPv6);
+	s.ipv6->d->srvList = d->srvList;
+	s.ipv6->d->hostList = d->hostList;
+	s.ipv6->d->domain = d->domain;
+	return s;
+}
+
 
 //----------------------------------------------------------------------------
 // ServiceLocalPublisher
