@@ -185,6 +185,7 @@ Client::~Client()
 	delete d->s5bman;
 	delete d->root;
 	delete d;
+	//fprintf(stderr, "\tClient::~Client\n");
 }
 
 void Client::connectToServer(ClientStream *s, const Jid &j, bool auth)
@@ -407,6 +408,14 @@ QString Client::groupChatNick(const QString &host, const QString &room) const
 	return QString();
 }
 
+bool Client::isStreamManagementActive() const {
+	ClientStream *cs = qobject_cast<ClientStream*>(d->stream);
+	if(cs)
+		return cs->isStreamManagementActive();
+	return false;
+}
+
+
 /*void Client::start()
 {
 	if(d->stream->old()) {
@@ -598,7 +607,7 @@ void Client::distribute(const QDomElement &x)
 	}
 }
 
-void Client::send(const QDomElement &x)
+void Client::send(const QDomElement &x, bool want_notify)
 {
 	if(!d->stream)
 		return;
@@ -617,13 +626,13 @@ void Client::send(const QDomElement &x)
 		//printf("bad stanza??\n");
 		return;
 	}
-
 	QString out = s.toString();
+	//qWarning() << "Out: " << out;
 	debug(QString("Client: outgoing: [\n%1]\n").arg(out));
 	emit xmlOutgoing(out);
 
 	//printf("x[%s] x2[%s] s[%s]\n", Stream::xmlToString(x).toLatin1(), Stream::xmlToString(e).toLatin1(), s.toString().toLatin1());
-	d->stream->write(s);
+	d->stream->write(s, want_notify);
 }
 
 void Client::send(const QString &str)
@@ -983,9 +992,9 @@ void Client::importRosterItem(const RosterItem &item)
 	debug(dstr + str);
 }
 
-void Client::sendMessage(const Message &m)
+void Client::sendMessage(const Message &m, bool want_notify)
 {
-	JT_Message *j = new JT_Message(rootTask(), m);
+	JT_Message *j = new JT_Message(rootTask(), m, want_notify);
 	j->go(true);
 }
 
@@ -1164,6 +1173,10 @@ void Client::handleIncoming(BSConnection *c)
 	d->ftman->stream_incomingReady(c);
 }
 
+void Client::handleSMAckResponse(int h) {
+	qDebug() << "handleSMAckResponse: h = " << h;
+}
+
 //---------------------------------------------------------------------------
 // LiveRosterItem
 //---------------------------------------------------------------------------
