@@ -112,7 +112,12 @@ void JT_Session::onGo()
 
 bool JT_Session::take(const QDomElement& x)
 {
-	if(!iqVerify(x, "", id()))
+	QString from = x.attribute("from");
+	if (!from.endsWith("chat.facebook.com")) {
+		// remove this code when chat.facebook.com is disabled completely
+		from.clear();
+	}
+	if(!iqVerify(x, from, id()))
 		return false;
 
 	if(x.attribute("type") == "result") {
@@ -847,12 +852,13 @@ static QDomElement oldStyleNS(const QDomElement &e)
 	return i;
 }
 
-JT_Message::JT_Message(Task *parent, const Message &msg)
+JT_Message::JT_Message(Task *parent, const Message &msg, bool want_notify)
 :Task(parent)
 {
 	m = msg;
 	if (m.id().isEmpty())
 		m.setId(id());
+	w_notify = want_notify;
 }
 
 JT_Message::~JT_Message()
@@ -863,7 +869,7 @@ void JT_Message::onGo()
 {
 	Stanza s = m.toStanza(&(client()->stream()));
 	QDomElement e = oldStyleNS(s.element());
-	send(e);
+	send(e, w_notify);
 	setSuccess();
 }
 
